@@ -8,9 +8,9 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#if defined(QT_NO_STL)
-# define DISABLE_QT_NO_STL
-# undef QT_NO_STL
+#if defined(TQT_NO_STL)
+# define DISABLE_TQT_NO_STL
+# undef TQT_NO_STL
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -888,8 +888,8 @@ DebugLine::DebugLine()
 #include "gpsimprocessor.moc"
 #endif
 
-// restore QT_NO_STL
-#if defined(DISABLE_QT_NO_STL)
-# undef DISABLE_QT_NO_STL
-# define QT_NO_STL
+// restore TQT_NO_STL
+#if defined(DISABLE_TQT_NO_STL)
+# undef DISABLE_TQT_NO_STL
+# define TQT_NO_STL
 #endif
