@@ -27,7 +27,7 @@
 
 //BEGIN class Language
 Language::Language( ProcessChain *processChain, KTechlab *parent, const TQString &name )
-	: TQObject(parent,name)
+	: TQObject(parent, name.utf8())
 {
 	p_ktechlab = parent;
 	p_processChain = processChain;
