@@ -61,7 +61,7 @@ class KVSSBSep : public TQWidget {
 
 //BEGIN class View
 View::View( Document *document, ViewContainer *viewContainer, uint viewAreaId, const char *name )
-	: TQWidget( viewContainer->viewArea(viewAreaId), name ? name : (const char *)("view_" + TQString::number(viewAreaId)) ),
+	: TQWidget( viewContainer->viewArea(viewAreaId), name ? name : TQString("view_%1").arg(TQString::number(viewAreaId)).latin1() ),
 	  KXMLGUIClient()
 {
 	m_dcopID = 0;
@@ -103,7 +103,7 @@ View::~View()
 
 TDEAction * View::action( const TQString & name ) const
 {
-	TDEAction * action = actionCollection()->action(name);
+	TDEAction * action = actionCollection()->action(name.utf8());
 	if ( !action )
 		kdError() << k_funcinfo << "No such action: " << name << endl;
 	return action;
