@@ -412,8 +412,8 @@ ViewArea *ViewArea::createViewArea( Position position, uint id )
 	
 	setOrientation( ( position == Right ) ? Qt::Horizontal : Qt::Vertical );
 	
-	p_viewArea1 = new ViewArea( this, p_viewContainer, m_id, (const char*)("viewarea_"+TQString::number(m_id)) );
-	p_viewArea2 = new ViewArea( this, p_viewContainer, id, (const char*)("viewarea_"+TQString::number(id)) );
+	p_viewArea1 = new ViewArea(this, p_viewContainer, m_id, TQString("viewarea_%1").arg(TQString::number(m_id)).latin1());
+	p_viewArea2 = new ViewArea(this, p_viewContainer, id, TQString("viewarea_%1").arg(TQString::number(id)).latin1());
 	
 	connect( p_viewArea1, TQT_SIGNAL(destroyed(TQObject* )), this, TQT_SLOT(viewAreaDestroyed(TQObject* )) );
 	connect( p_viewArea2, TQT_SIGNAL(destroyed(TQObject* )), this, TQT_SLOT(viewAreaDestroyed(TQObject* )) );
@@ -559,7 +559,7 @@ void ViewArea::restoreState( TDEConfig *config, int id, const TQString &groupNam
 			if ( contains.size() >= 1 )
 			{
 				int viewArea1Id = contains[0];
-				p_viewArea1 = new ViewArea( this, p_viewContainer, viewArea1Id, (const char*)("viewarea_"+TQString::number(viewArea1Id)) );
+				p_viewArea1 = new ViewArea(this, p_viewContainer, viewArea1Id, TQString("viewarea_%1").arg(TQString::number(viewArea1Id)).latin1());
 				connect( p_viewArea1, TQT_SIGNAL(destroyed(TQObject* )), this, TQT_SLOT(viewAreaDestroyed(TQObject* )) );
 				p_viewArea1->restoreState( config, viewArea1Id, groupName );
 				p_viewArea1->show();
@@ -568,7 +568,7 @@ void ViewArea::restoreState( TDEConfig *config, int id, const TQString &groupNam
 			if ( contains.size() >= 2 )
 			{
 				int viewArea2Id = contains[1];
-				p_viewArea2 = new ViewArea( this, p_viewContainer, viewArea2Id, (const char*)("viewarea_"+TQString::number(viewArea2Id)) );
+				p_viewArea2 = new ViewArea(this, p_viewContainer, viewArea2Id, TQString("viewarea_%1").arg(TQString::number(viewArea2Id)).latin1());
 				connect( p_viewArea2, TQT_SIGNAL(destroyed(TQObject* )), this, TQT_SLOT(viewAreaDestroyed(TQObject* )) );
 				p_viewArea2->restoreState( config, viewArea2Id, groupName );
 				p_viewArea2->show();
